@@ -6,7 +6,7 @@ import wsme.tests.protocol
 
 try:
     import simplejson as json
-except:
+except ImportError:
     import json  # noqa
 
 from wsme.rest.json import fromjson, tojson, parse
@@ -148,6 +148,7 @@ class MiniCrud(object):
             ref.name = u('test')
         return CRUDResult(ref, u('delete'))
 
+
 wsme.tests.protocol.WSTestRoot.crud = MiniCrud()
 
 
