@@ -206,6 +206,19 @@ Value: 'v3'. Value should be one of: v., v.",
         self.assertRaises(exc.InvalidInput, setattr, obj, 'alist', 12)
         self.assertRaises(exc.InvalidInput, setattr, obj, 'alist', [2, 'a'])
 
+    def test_attribute_validation_minimum(self):
+        class ATypeInt(object):
+            attr = types.IntegerType(minimum=1, maximum=5)
+
+        types.register_type(ATypeInt)
+
+        obj = ATypeInt()
+        obj.attr = 2
+
+        # comparison between 'zero' value and intger minimum (1) raises a
+        # TypeError which must be wrapped into an InvalidInput exception
+        self.assertRaises(exc.InvalidInput, setattr, obj, 'attr', 'zero')
+
     def test_text_attribute_conversion(self):
         class SType(object):
             atext = types.text
@@ -433,8 +446,8 @@ Value: 'v3'. Value should be one of: v., v.",
         assert c.s == six.u('test')
 
     def test_array_eq(self):
-        l = [types.ArrayType(str)]
-        assert types.ArrayType(str) in l
+        ell = [types.ArrayType(str)]
+        assert types.ArrayType(str) in ell
 
     def test_array_sample(self):
         s = types.ArrayType(str).sample()
